import { Socket } from "./socket";
import { WorkflowExecutionContext } from "./workflow";

/** can be set before and manipulated within workflow blocks */
export interface BlockContext<DataType = any> {
  data?: DataType;
}

export interface BlockExecutionResult<DataType = any> extends BlockContext<DataType> {
  socketName: string;
}

export interface BlockExecutionContext<
  DataType = any,
  ConfigurationType = {
    [key: string]: any;
    timeout?: number;
    method?: "get" | "post" | "put" | "head" | "delete" | "patch";
    authHeader?: string;
  }
> extends BlockContext<DataType> {
  // dataSchema?: any;
  configuration?: ConfigurationType;
  socketName: string;
}

export interface WorkflowBlockDefinition {
  executeBlock(
    context: BlockExecutionContext,
    workflowContext: WorkflowExecutionContext
  ): Promise<BlockExecutionResult> | Promise<void> | void;
  getSockets(): Socket[];

  /**
   * Can be JSONSchema7 or equivalent, should describe, how the blockExecutionContext.configuration object should look like
   */
  getConfigurationSchema(): any;
}


export interface WorkflowTriggerBlockDefinition extends WorkflowBlockDefinition {
  getTriggerName(): string;
}

export interface WorkflowBlock {
  id: string;
  definitionId: string;
  configuration?: { [key: string]: any };
}

