export enum WorkflowLogLevel {
  INFO = "info",
  DEBUG = "debug",
  WARN = "warn",
  ERROR = "error"
}

export interface WorkflowLog {
  timestamp: number;
  blockId: string;
  blockName?: string;
  socketName: string;
  text: string;
  extra?: string;
  level: WorkflowLogLevel;
}

export interface WorkflowLogger {
  addLog(log: WorkflowLog): Promise<void>;
  info(text: string, extra?: string): Promise<void>;
  debug(text: string, extra?: string): Promise<void>;
  warn(text: string, extra?: string): Promise<void>;
  error(text: string, extra?: string): Promise<void>;
  getLogs(): WorkflowLog[];
  setContext(blockId: string, blockName: string, socketName: string): void;
}

export class DefaultWorkflowLogger implements WorkflowLogger {
  private logs: WorkflowLog[] = [];

  private blockId: string;
  private blockName: string;
  private socketName: string;

  public setContext(blockId: string, blockName: string, socketName: string): void {
    this.blockId = blockId;
    this.blockName = blockName;
    this.socketName = socketName;
  }
  public async addLog(log: WorkflowLog): Promise<void> {
    this.logs.push(log);
  }
  public async debug(text: string, extra?: string): Promise<void> {
    this.addLog({
      blockId: this.blockId,
      blockName: this.blockName,
      socketName: this.socketName,
      text,
      extra,
      timestamp: Date.now(),
      level: WorkflowLogLevel.DEBUG
    });
  }
  public async error(text: string, extra?: string): Promise<void> {
    this.addLog({
      blockId: this.blockId,
      blockName: this.blockName,
      socketName: this.socketName,
      text,
      extra,
      timestamp: Date.now(),
      level: WorkflowLogLevel.ERROR
    });
  }
  public async info(text: string, extra?: string): Promise<void> {
    this.addLog({
      blockId: this.blockId,
      blockName: this.blockName,
      socketName: this.socketName,
      text,
      extra,
      timestamp: Date.now(),
      level: WorkflowLogLevel.INFO
    });
  }
  public async warn(text: string, extra?: string): Promise<void> {
    this.addLog({
      blockId: this.blockId,
      blockName: this.blockName,
      socketName: this.socketName,
      text,
      extra,
      timestamp: Date.now(),
      level: WorkflowLogLevel.WARN
    });
  }

  public getLogs(): WorkflowLog[] {
    return this.logs;
  }
}
