import path from "path";
import { defineConfig } from "vite";
import dts from "vite-plugin-dts";

export default defineConfig({
  base: "./",
  plugins: [dts()],
  build: {
    lib: {
      name: "@smallstack/workflow-engine",
      entry: path.resolve(__dirname, "lib/index.ts"),
      fileName: (format, entryName) => {
        if (format === "cjs") return `${entryName}.cjs`;
        return `${entryName}.${format}.js`;
      },
    },
  },
  test: {
    globals: true,
    environment: "node",
    include: ["lib/**/*.test.ts"],
    reporters: ["default", "junit"],
    outputFile: { junit: "test-results/junit.xml" },
    coverage: {
      provider: "v8",
      include: ["lib/**"],
      exclude: [
        "node_modules/**",
        "lib/index.ts",
        "lib/**/index.ts",
        "lib/**/*.test.ts",
      ],
      reporter: ["lcov", "clover", "text-summary"],
      reportsDirectory: "coverage",
      thresholds: {
        statements: 100,
        branches: 100,
        functions: 100,
        lines: 100,
      },
    },
  },
});
